@@ -146,7 +146,7 @@ class slot_conflict_handler:
             if self.debug:
                 writemsg("\nNew configuration:\n", noiselevel=-1)
                 for pkg in config:
-                    writemsg("   %s\n" % (pkg,), noiselevel=-1)
+                    writemsg(f"   {pkg}\n", noiselevel=-1)
                 writemsg("\n", noiselevel=-1)
 
             new_solutions = self._check_configuration(
@@ -258,9 +258,9 @@ class slot_conflict_handler:
         )
 
         for root, slot_atom, pkgs in self.all_conflicts:
-            msg.append("%s" % (slot_atom,))
+            msg.append(f"{slot_atom}")
             if root != self.depgraph._frozen_config._running_root.root:
-                msg.append(" for %s" % (root,))
+                msg.append(f" for {root}")
             msg.append("\n\n")
 
             for pkg in pkgs:
@@ -523,7 +523,7 @@ class slot_conflict_handler:
 
                     def highlight_violations(atom, version, use, slot_violated):
                         """Colorize parts of an atom"""
-                        atom_str = "%s" % (atom,)
+                        atom_str = f"{atom}"
                         colored_idx = set()
                         if version:
                             op = atom.operator
@@ -614,7 +614,7 @@ class slot_conflict_handler:
 
                             atom_str = (
                                 atom_str[:use_part_start]
-                                + "[%s]" % (",".join(new_tokens),)
+                                + f"[{','.join(new_tokens)}]"
                                 + atom_str[use_part_end + 1 :]
                             )
 
@@ -638,16 +638,14 @@ class slot_conflict_handler:
                         else:
                             use_display = ""
                         if atom.soname:
-                            msg.append(
-                                "%s required by %s %s\n" % (atom, parent, use_display)
-                            )
+                            msg.append(f"{atom} required by {parent} {use_display}\n")
                         elif isinstance(parent, PackageArg):
                             # For PackageArg it's
                             # redundant to display the atom attribute.
-                            msg.append("%s\n" % (parent,))
+                            msg.append(f"{parent}\n")
                         elif isinstance(parent, AtomArg):
                             msg.append(2 * indent)
-                            msg.append("%s (Argument)\n" % (atom,))
+                            msg.append(f"{atom} (Argument)\n")
                         else:
                             # Display the specific atom from SetArg or
                             # Package types.
@@ -675,7 +673,7 @@ class slot_conflict_handler:
                             if version_violated or slot_violated:
                                 self.is_a_version_conflict = True
 
-                            cur_line = "%s required by %s %s\n" % (
+                            cur_line = "{} required by {} {}\n".format(
                                 atom_str,
                                 parent,
                                 use_display,
@@ -736,7 +734,7 @@ class slot_conflict_handler:
             )
             msg.append("!!! package(s) cannot be rebuilt for the reason(s) shown:\n\n")
             for ppkg, reason in need_rebuild.items():
-                msg.append("%s%s: %s\n" % (indent, ppkg, reason))
+                msg.append(f"{indent}{ppkg}: {reason}\n")
             msg.append("\n")
 
         msg.append("\n")
@@ -784,7 +782,7 @@ class slot_conflict_handler:
                     indent
                     + "- "
                     + pkg.cpv
-                    + " (Change USE: %s" % " ".join(changes)
+                    + f" (Change USE: {' '.join(changes)}"
                     + ")\n"
                 )
             mymsg += "\n"
@@ -975,7 +973,7 @@ class slot_conflict_handler:
         if self.debug:
             writemsg("All involved flags:\n", noiselevel=-1)
             for idx, involved_flags in enumerate(all_involved_flags):
-                writemsg("   %s\n" % (config[idx],), noiselevel=-1)
+                writemsg(f"   {config[idx]}\n", noiselevel=-1)
                 for flag, state in involved_flags.items():
                     writemsg("     " + flag + ": " + state + "\n", noiselevel=-1)
 
@@ -1066,7 +1064,7 @@ class slot_conflict_handler:
                         inner_first = False
                     else:
                         msg += ", "
-                    msg += flag + ": %s" % (state,)
+                    msg += flag + f": {state}"
                 msg += "}"
             msg += "]\n"
             writemsg(msg, noiselevel=-1)
@@ -1281,7 +1279,7 @@ class _solution_candidate_generator:
             return self.value == other.value
 
         def __str__(self):
-            return "%s" % (self.value,)
+            return f"{self.value}"
 
     def __init__(self, all_involved_flags):
         # A copy of all_involved_flags with all "cond" values
