@@ -52,7 +52,6 @@ except ImportError as e:
     raise
 
 try:
-
     import portage.proxy.lazyimport
     import portage.proxy as proxy
 
@@ -265,10 +264,10 @@ class _unicode_func_wrapper:
             _unicode_encode(x, encoding=encoding, errors="strict") for x in args
         ]
         if kwargs:
-            wrapped_kwargs = dict(
-                (k, _unicode_encode(v, encoding=encoding, errors="strict"))
+            wrapped_kwargs = {
+                k: _unicode_encode(v, encoding=encoding, errors="strict")
                 for k, v in kwargs.items()
-            )
+            }
         else:
             wrapped_kwargs = {}
 
@@ -362,7 +361,7 @@ class _eintr_func_wrapper:
             try:
                 rval = self._func(*args, **kwargs)
                 break
-            except EnvironmentError as e:
+            except OSError as e:
                 if e.errno != errno.EINTR:
                     raise
 
@@ -638,7 +637,6 @@ class _trees_dict(dict):
 def create_trees(
     config_root=None, target_root=None, trees=None, env=None, sysroot=None, eprefix=None
 ):
-
     if trees is None:
         trees = _trees_dict()
     elif not isinstance(trees, _trees_dict):
@@ -664,7 +662,6 @@ def create_trees(
     if settings["ROOT"] == "/" and settings["EPREFIX"] == const.EPREFIX:
         trees._running_eroot = trees._target_eroot
     else:
-
         # When ROOT != "/" we only want overrides from the calling
         # environment to apply to the config that's associated
         # with ROOT != "/", so pass a nearly empty dict for the env parameter.
@@ -688,12 +685,23 @@ def create_trees(
 
         if depcachedir is not None:
             clean_env["PORTAGE_DEPCACHEDIR"] = depcachedir
-        settings = config(
+        mysettings = config(
             config_root=None, target_root="/", env=clean_env, sysroot="/", eprefix=None
         )
-        settings.lock()
-        trees._running_eroot = settings["EROOT"]
-        myroots.append((settings["EROOT"], settings))
+        mysettings.lock()
+        trees._running_eroot = mysettings["EROOT"]
+        myroots.append((mysettings["EROOT"], mysettings))
+
+        if settings["SYSROOT"] != "/" and settings["SYSROOT"] != settings["ROOT"]:
+            mysettings = config(
+                config_root=settings["SYSROOT"],
+                target_root=settings["SYSROOT"],
+                env=clean_env,
+                sysroot=settings["SYSROOT"],
+                eprefix="",
+            )
+            mysettings.lock()
+            myroots.append((mysettings["EROOT"], mysettings))
 
     for myroot, mysettings in myroots:
         trees[myroot] = portage.util.LazyItemsDict(trees.get(myroot, {}))
@@ -792,7 +800,6 @@ def _reset_legacy_globals():
 
 
 class _LegacyGlobalProxy(proxy.objectproxy.ObjectProxy):
-
     __slots__ = ("_name",)
 
     def __init__(self, name):
